@@ -740,7 +740,7 @@ func getJaegerSelfProvSimpleProd(instanceName, namespace string, nodeCount int32
 			},
 			Strategy: v1.DeploymentStrategyProduction,
 			Storage: v1.JaegerStorageSpec{
-				Type: v1.JaegerESStorage,
+				Type: "elasticsearch",
 				Elasticsearch: v1.ElasticsearchSpec{
 					NodeCount: nodeCount,
 					Resources: &corev1.ResourceRequirements{
